Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(352)

Unified Diff: ui/views/animation/test/ink_drop_ripple_test_api.h

Issue 1937103003: Rename of InkDropAnimation classes to InkDropRipple. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Removed test_ink_drop_animation_observer.h from views.gyp and doc update. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/animation/test/ink_drop_ripple_test_api.h
diff --git a/ui/views/animation/test/ink_drop_animation_test_api.h b/ui/views/animation/test/ink_drop_ripple_test_api.h
similarity index 54%
rename from ui/views/animation/test/ink_drop_animation_test_api.h
rename to ui/views/animation/test/ink_drop_ripple_test_api.h
index d10c73dd255268c8ffa9d1f3ac9876368c840054..7581392975f0799fe9709d96d48e6b4430e6bc5a 100644
--- a/ui/views/animation/test/ink_drop_animation_test_api.h
+++ b/ui/views/animation/test/ink_drop_ripple_test_api.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef UI_VIEWS_ANIMATION_TEST_INK_DROP_ANIMATION_TEST_API_H_
-#define UI_VIEWS_ANIMATION_TEST_INK_DROP_ANIMATION_TEST_API_H_
+#ifndef UI_VIEWS_ANIMATION_TEST_INK_DROP_RIPPLE_TEST_API_H_
+#define UI_VIEWS_ANIMATION_TEST_INK_DROP_RIPPLE_TEST_API_H_
#include <vector>
@@ -16,19 +16,19 @@ class LayerAnimator;
} // namespace ui
namespace views {
-class InkDropAnimation;
+class InkDropRipple;
namespace test {
// Test API to provide internal access to an InkDropAnimation instance. This can
// also be used to control the animations via the
// ui::test::MultiLayerAnimatorTestController API.
-class InkDropAnimationTestApi
+class InkDropRippleTestApi
: public ui::test::MultiLayerAnimatorTestController,
public ui::test::MultiLayerAnimatorTestControllerDelegate {
public:
- explicit InkDropAnimationTestApi(InkDropAnimation* ink_drop_animation);
- ~InkDropAnimationTestApi() override;
+ explicit InkDropRippleTestApi(InkDropRipple* ink_drop_ripple);
+ ~InkDropRippleTestApi() override;
// Gets the opacity of the ink drop.
virtual float GetCurrentOpacity() const = 0;
@@ -37,21 +37,20 @@ class InkDropAnimationTestApi
std::vector<ui::LayerAnimator*> GetLayerAnimators() override;
protected:
- InkDropAnimation* ink_drop_animation() {
- return static_cast<const InkDropAnimationTestApi*>(this)
- ->ink_drop_animation();
+ InkDropRipple* ink_drop_ripple() {
+ return static_cast<const InkDropRippleTestApi*>(this)->ink_drop_ripple();
}
- InkDropAnimation* ink_drop_animation() const { return ink_drop_animation_; }
+ InkDropRipple* ink_drop_ripple() const { return ink_drop_ripple_; }
private:
- // The InkDropedAnimation to provide internal access to.
- InkDropAnimation* ink_drop_animation_;
+ // The InkDropedRipple to provide internal access to.
+ InkDropRipple* ink_drop_ripple_;
- DISALLOW_COPY_AND_ASSIGN(InkDropAnimationTestApi);
+ DISALLOW_COPY_AND_ASSIGN(InkDropRippleTestApi);
};
} // namespace test
} // namespace views
-#endif // UI_VIEWS_ANIMATION_TEST_INK_DROP_ANIMATION_TEST_API_H_
+#endif // UI_VIEWS_ANIMATION_TEST_INK_DROP_RIPPLE_TEST_API_H_
« no previous file with comments | « ui/views/animation/test/ink_drop_animation_test_api.cc ('k') | ui/views/animation/test/ink_drop_ripple_test_api.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -16,19 +16,19 @@ class LayerAnimator;
namespace test {
-// Test API to provide internal access to an InkDropAnimation instance. This can
+// Test API to provide internal access to an InkDropRipple instance. This can
// also be used to control the animations via the
// ui::test::MultiLayerAnimatorTestController API.
This is Rietveld 408576698